API docs for “spamfighter.api.message.test.test_firewall.FirewallRulesGetCommandTestCase”

# Class s.a.m.t.t.FirewallRulesGetCommandTestCase(unittest.TestCase):

Part of spamfighter.api.message.test.test_firewall View Source View In Hierarchy

Тест на `spamfighter.api.message.firewall.FirewallRulesGetCommand`.

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testRun | Undocumented

def setUp(self): (source)
Undocumented
def tearDown(self): (source)
Undocumented
def testRun(self): (source)
Undocumented